summaryrefslogtreecommitdiff
path: root/emulator/le.c
diff options
context:
space:
mode:
authorMarcel Holtmann <marcel@holtmann.org>2014-12-17 07:18:00 +0100
committerMarcel Holtmann <marcel@holtmann.org>2014-12-17 07:18:00 +0100
commitf91750396153f9804b97ada324eb3ec3f28891e5 (patch)
treea03e203a694b4c20457a7ccaf259190147082c11 /emulator/le.c
parent4a3f1493295a624f77c2445363f6f3a11a71004f (diff)
downloadbluez-f91750396153f9804b97ada324eb3ec3f28891e5.tar.gz
emulator: Enable the LE feature bit for supporting LL Privacy
Diffstat (limited to 'emulator/le.c')
-rw-r--r--emulator/le.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/emulator/le.c b/emulator/le.c
index 26b87be1d..849b5368a 100644
--- a/emulator/le.c
+++ b/emulator/le.c
@@ -258,7 +258,7 @@ static void reset_defaults(struct bt_le *hci)
//hci->le_features[0] |= 0x08; /* Slave-initiated Features Exchange */
hci->le_features[0] |= 0x10; /* LE Ping */
hci->le_features[0] |= 0x20; /* LE Data Packet Length Extension */
- //hci->le_features[0] |= 0x40; /* LL Privacy */
+ hci->le_features[0] |= 0x40; /* LL Privacy */
hci->le_features[0] |= 0x80; /* Extended Scanner Filter Policies */
memset(hci->le_random_addr, 0, sizeof(hci->le_random_addr));
@@ -716,8 +716,8 @@ static void cmd_le_set_adv_parameters(struct bt_le *hci,
return;
}
- /* Valid range for own address type is 0x00 to 0x01 */
- if (cmd->own_addr_type > 0x01) {
+ /* Valid range for own address type is 0x00 to 0x03 */
+ if (cmd->own_addr_type > 0x03) {
cmd_status(hci, BT_HCI_ERR_INVALID_PARAMETERS,
BT_HCI_CMD_LE_SET_ADV_PARAMETERS);
return;
@@ -885,8 +885,8 @@ static void cmd_le_set_scan_parameters(struct bt_le *hci,
return;
}
- /* Valid range for own address type is 0x00 to 0x01 */
- if (cmd->own_addr_type > 0x01) {
+ /* Valid range for own address type is 0x00 to 0x03 */
+ if (cmd->own_addr_type > 0x03) {
cmd_status(hci, BT_HCI_ERR_INVALID_PARAMETERS,
BT_HCI_CMD_LE_SET_SCAN_PARAMETERS);
return;
@@ -957,8 +957,8 @@ static void cmd_le_create_conn(struct bt_le *hci,
return;
}
- /* Valid range for own address type is 0x00 to 0x01 */
- if (cmd->own_addr_type > 0x01) {
+ /* Valid range for own address type is 0x00 to 0x03 */
+ if (cmd->own_addr_type > 0x03) {
cmd_status(hci, BT_HCI_ERR_INVALID_PARAMETERS,
BT_HCI_CMD_LE_CREATE_CONN);
return;